function varargout=wormLocomotion(type,splineFile,stageFile,frameRate,calibx,caliby,point,oldStyle,frames)
if nargin==8
    frames='all';
end

%find worm velocity
stageData=load(stageFile);
splineData=load(splineFile);

if length(splineData(1,:))==14 || length(splineData(1,:))==27
    ventralData=splineData(1:2:end-1,1);
    splineData=splineData(:,2:14);
else
    splineData=splineData(:,1:13);
end

xi=1:2:length(splineData(:,1)-1);
yi=2:2:length(splineData(:,1));

if oldStyle
    x=splineData(xi,:);
    y=splineData(yi,:);
else
    x=splineData(xi,:)*calibx;
    y=splineData(yi,:)*caliby;  %convert from pixels back into micrometers
end

%*****All further analysis should be done in micrometers*****

%1.) cut movement down from 15fps to 3fps

if frameRate==15
    if oldStyle
        xNew=x(21:5:end,:);
        yNew=y(21:5:end,:);
    else
        xNew=x(1:5:end,:);
        yNew=y(1:5:end,:);
    end
    newFrameRate=3;
elseif frameRate==3
    xNew=x;
    yNew=y;
    newFrameRate=3;
elseif frameRate==1
    xNew=x;
    yNew=y;
    newFrameRate=1;
end

xComp=[];
yComp=[];
%2.) compensate for stage movement
for i=1:length(xNew(:,1))    %for every third element in the 3fps x/y pair, compensate for the stage movement
    [xSpline,ySpline]=compensateForStage(xNew(i,:),yNew(i,:),i,stageData,newFrameRate,oldStyle);
    xComp=[xComp; xSpline];
    yComp=[yComp; ySpline];
end

if ~strcmp(frames,'all')
    xComp=xComp(frames(1):frames(2),:);
    yComp=yComp(frames(1):frames(2),:);
end

%3.) Find the centroid of the points
xC=[];
yC=[];
for i=1:length(xComp(:,1))
    xC=[xC mean(xComp(i,:))];
    yC=[yC mean(yComp(i,:))];
end

%Do the desired calculations
if strcmp(type,'Amplitude')
    amp=[];
    wormLength=[];
    for i=1:length(xC)-1
        movementVector=[xC(i+1)-xC(i) yC(i+1)-yC(i)];
        perpVector=[-movementVector(2) movementVector(1)];
        unitPerpVector=perpVector/norm(perpVector);
        proj=[];
        for j=1:13
            a=[xComp(i,j)-xC(i) yComp(i,j)-yC(i)];  %a is the vector from the point of interest to the centroid
            proj=[proj dot(a,unitPerpVector)];
        end
        len=[];
        for k=2:13
            len=[len sqrt((xComp(i,k)-xComp(i,k-1))^2+(yComp(i,k)-yComp(i,k-1))^2)];
        end
        amp=[amp max(proj)-min(proj)];
        wormLength=[wormLength sum(len)];
    end

    varargout{1}=amp;
    varargout{2}=mean(amp)/mean(wormLength);
elseif strcmp(type,'Speed')
    
    if point~=0
        xC=xComp(:,point);yC=yComp(:,point);
    end
    
%     if ~strcmp(point,'cog')
%         xC=xComp(:,point);yC=yComp(:,point);
%     end

    speed=zeros(1,length(xComp(:,1))-1);
    for i=2:length(xComp(:,1))
        dist=ptDist(xC(i-1),yC(i-1),xC(i),yC(i));
        speed(i-1)=dist*newFrameRate;
    end
    varargout{1}=speed;
elseif strcmp(type,'Direction')
    forwardCount=0;
    backwardCount=0;
    forwardDist=0;
    backwardDist=0;
    for i=1:length(xC)-1
        movementVector=[xC(i+1)-xC(i) yC(i+1)-yC(i)];
        headVector=[xComp(i)-xC(i) yComp(i)-yC(i)];
        unitHeadVector=headVector/norm(headVector);
        proj=dot(movementVector,unitHeadVector);
        if proj>=0
            forwardCount=forwardCount+1;
            forwardDist=forwardDist+sqrt((xC(i+1)-xC(i))^2+(yC(i+1)-yC(i))^2);
        elseif proj<0
            backwardCount=backwardCount+1;
            backwardDist=backwardDist+sqrt((xC(i+1)-xC(i))^2+(yC(i+1)-yC(i))^2);
        end
    end
    varargout{1}=[forwardCount backwardCount];
    varargout{2}=[forwardDist backwardDist];
elseif strcmp(type,'Plot')
%     if ~strcmp(point,'cog')
%         xC=xComp(:,point);yC=yComp(:,point);
%     end
    if point~=0
        xC=xComp(:,point);yC=yComp(:,point);
    end
    fig=figure;
    plot(xC,yC,'.-')
    hold on
    plot(xC(1),yC(1),'xr','MarkerSize',12,'LineWidth',2)
    title('Worm path (''X'' marks starting point)')
    xlabel('x position (um)');
    ylabel('y position (um)');
    hold off
    varargout{1}=fig;
elseif strcmp(type,'Distance')
%     if ~strcmp(point,'cog')
%         xC=xComp(:,point);yC=yComp(:,point);
%     end   
    if point~=0
        xC=xComp(:,point);yC=yComp(:,point);
    end
    distance=[];
    for i=2:length(xC)
        distance=[distance sqrt((xC(i)-xC(i-1))^2+(yC(i)-yC(i-1))^2)];
    end
    varargout{1}=distance;
    
    netDist=ptDist(xC(1),yC(1),xC(end),yC(end));
    
    varargout{2}=netDist;
elseif strcmp(type,'Path')
%     if ~strcmp(point,'cog')
%         xC=xComp(:,point);yC=yComp(:,point);
%     end
    if point~=0
        xC=xComp(:,point);yC=yComp(:,point);
    end
    varargout{1}=xC;
    varargout{2}=yC;
end
    
    
function [xcl,ycl]=compensateForStage(xcl,ycl,frameNumber,stageMovement,frameRate,oldStyle)
%xcl, ycl are row vectors;
if oldStyle
    rowNum=floor((frameNumber-1)/frameRate)+1;    %rowNum tells you the most recent stage movement row number.
else
    rowNum=floor((frameNumber+1)/frameRate)+1;
end
% if xcl ~= [0 0 0 0 0 0 0 0 0 0 0 0 0]
xStageMovement=stageMovement(:,1);
yStageMovement=stageMovement(:,2);
xMove=sum(xStageMovement(1:rowNum));    %assumes input is in micrometers, not pixels 
yMove=sum(yStageMovement(1:rowNum));
xcl=xcl+xMove;
ycl=ycl+yMove;
% end